===========
pymanifesto
===========


.. image:: https://img.shields.io/pypi/v/pymanifesto.svg
        :target: https://pypi.python.org/pypi/pymanifesto

.. image:: https://img.shields.io/travis/shimst3r/pymanifesto.svg
        :target: https://travis-ci.org/shimst3r/pymanifesto

.. image:: https://readthedocs.org/projects/pymanifesto/badge/?version=latest
        :target: https://pymanifesto.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




pymanifesto connects you to the Manifesto Project's database using Python.


* Free software: GNU General Public License v3
* Documentation: https://pymanifesto.readthedocs.io.

About the Manifesto Project
---------------------------

Quoting from the project website_:

  The Manifesto Project provides the scientific community with parties’
  policy positions derived from a content analysis of parties’ electoral
  manifestos. It covers over 1000 parties from 1945 until today in over
  50 countries on five continents. The DFG-funded MARPOR project continues
  the work of the Manifesto Research Group (MRG) and the Comparative
  Manifestos Project (CMP). On this website you find the Manifesto Project
  Dataset containing the parties' policy preferences generated by the project.
  You also find coded and uncoded election manifestos of the parties in
  the dataset as well as information and links to many applications for
  the dataset, related projects and publications etc.

Features
--------

``pymanifesto`` is a Python interface to the `Manifesto Project API`_.

The following API endpoints are implemented:

* ``api_list_core_versions``

The following API endpoints will be implemented:

* ``api_list_metadata_versions``
* ``api_get_core``
* ``api_metadata``
* ``api_texts_and_annotations``
* ``api_get_core_codebook``
* ``api_get_core_citation``
* ``api_get_corpus_citation``

Credits
-------

This package was created with Cookiecutter_ and the
`audreyr/cookiecutter-pypackage`_ project template.


.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`Manifesto Project API`: https://manifesto-project.wzb.eu/information/documents/api
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _website: https://manifestoproject.wzb.eu
